@@ -1,7 +1,7 @@
 use 5.014;
 
 package Mojo::UserAgent::Mockable::Request::Compare;
-$Mojo::UserAgent::Mockable::Request::Compare::VERSION = '1.11';
+$Mojo::UserAgent::Mockable::Request::Compare::VERSION = '1.2';
 # VERSION
 
 # ABSTRACT: Helper class for Mojo::UserAgent::Mockable that compares two Mojo::Message::Request instances
@@ -14,6 +14,7 @@ use Safe::Isa qw{$_isa};
 
 has compare_result => '';
 has ignore_headers => sub { [] };
+has ignore_body => '';
 
 sub compare {
     my ($self, $r1, $r2) = @_;
@@ -37,7 +38,7 @@ sub compare {
         return 0;
     }
 
-    if ( $r1->body ne $r2->body ) {
+    if ( !$self->ignore_body && $r1->body ne $r2->body ) {
         $self->compare_result('Body mismatch');
         return 0;
     }
@@ -146,7 +147,7 @@ Mojo::UserAgent::Mockable::Request::Compare - Helper class for Mojo::UserAgent::
 
 =head1 VERSION
 
-version 1.11
+version 1.2
 
 =head1 ATTRIBUTES
 
